@@ -93,7 +93,7 @@ class MeshEncoder:
         """
         process = subprocess.Popen(
             ["./3DAlignment", self.temp_path.with_suffix("").as_posix()],
-            cwd=CURRENT_DIR / "Executable",
+            cwd=(CURRENT_DIR / "Executable").as_posix(),
             stdin=subprocess.PIPE,
             stdout=subprocess.PIPE,
             stderr=subprocess.PIPE,
@@ -108,7 +108,7 @@ class MeshEncoder:
             GENERATED_FILES_NAMES, OUTPUT_NAME_TEMPLATES
         ):
             shutil.move(
-                os.path.join(CURRENT_DIR / "Executable", file),
+                os.path.join((CURRENT_DIR / "Executable").as_posix(), file),
                 (
                     self.temp_dir_path / out_file.format(self.file_name)
                 ).as_posix(),
@@ -178,7 +178,7 @@ class LightFieldDistance:
             stdin=subprocess.PIPE,
             stdout=subprocess.PIPE,
             stderr=subprocess.PIPE,
-            cwd=CURRENT_DIR / "Executable",
+            cwd=(CURRENT_DIR / "Executable").as_posix(),
         )
 
         output, err = process.communicate()
